mapquest.core


embellishcljmacro

(embellish test k v map)

if test is truthy, assoc k and v onto map, else return map

if test is truthy, assoc k and v onto map, else return map
sourceraw docstring

keyword-in-setcljmacro

(keyword-in-set name k set)

defines a predicate that accepts a map, and tests a key from that map for set membership

defines a predicate that accepts a map, and tests a key from that map for set membership
sourceraw docstring

merge-leftclj

(merge-left & maps)

preserves keys in earlier maps

preserves keys in earlier maps
sourceraw docstring

reset-indexclj

(reset-index map)

takes a map, and assigns its values to keys starting from 0

takes a map, and assigns its values to keys starting from 0
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries