(embellish test k v map)if test is truthy, assoc k and v onto map, else return map
if test is truthy, assoc k and v onto map, else return map
(keyword-in-set name k set)defines a predicate that accepts a map, and tests a key from that map for set membership
defines a predicate that accepts a map, and tests a key from that map for set membership
(merge-left & maps)preserves keys in earlier maps
preserves keys in earlier maps
(reset-index map)takes a map, and assigns its values to keys starting from 0
takes a map, and assigns its values to keys starting from 0
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |